"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterErrorsUsingInlineConfiguration = filterErrorsUsingInlineConfiguration;

function filterErrorsUsingInlineConfiguration(schemaSourceMap, inlineConfiguration, errors, startingRules) {
  let filteredErrors = [];

  for (let i = 0; i < errors.length; i++) {
    let error = errors[i];
    let errorLine = error.locations[0].line;
    let activeRulesAtLine = computeActiveRulesAtLine(startingRules, inlineConfiguration, schemaSourceMap.getFileStartingLines(), errorLine);

    if (activeRulesAtLine.has(error.ruleName)) {
      filteredErrors.append(error);
    }
  }

  console.log(inlineConfiguration);
  console.log(schemaSourceMap.getFileStartingLines());
  return errors;
}

class StateMachine {
  constructor(startingRules, inlineConfiguration, sourceMap) {
    this.startingRules = startingRules;
    this.inlineConfiguration = inlineConfiguration;
    this.sourceMap = sourceMap;
    this.i = 0;
  }

  advanceToLine(line) {
    if (line < this.i) {
      throw 'Cannot go backwards';
    }
  }

} // At the beginning of each file, reset back to starting rules.


function computeActiveRulesAtLine(startingRules, inlineConfiguration, fileStartingLines, errorLine) {
  let currentRules = new Set(startingRules.map(function (rule) {
    return rule.name;
  }));

  for (let i = 0; i < inlineConfiguration.length; i++) {
    let inlineOverride = inlineConfiguration[i];

    switch (inlineOverride.command) {
      case 'enable':
        inlineOverride.rules.map(function (rule) {
          currentRules.add(rule);
        });
        break;

      case 'disable':
        inlineOverride.rules.map(function (rule) {
          currentRules.delete(rule);
        });
        break;
    }

    if (i == errorLine) {
      return currentRules;
    }
  }

  return currentRules;
}