"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EnumValuesSortedAlphabetically = EnumValuesSortedAlphabetically;

var _validation_error = require("../validation_error");

var _listIsAlphabetical = _interopRequireDefault(require("../util/listIsAlphabetical"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function EnumValuesSortedAlphabetically(context) {
  return {
    EnumTypeDefinition(node, key, parent, path, ancestors) {
      const enumValues = node.values.map(val => {
        return val.name.value;
      });
      const {
        isSorted,
        sortedList
      } = (0, _listIsAlphabetical.default)(enumValues);

      if (!isSorted) {
        context.reportError(new _validation_error.ValidationError('enum-values-sorted-alphabetically', `The enum \`${node.name.value}\` should be sorted alphabetically. ` + `Expected sorting: ${sortedList.join(', ')}`, [node]));
      }
    }

  };
}